@@ -15,34 +15,35 @@ from .prediction import Prediction
 from .sentiment_analysis import SentimentAnalysis
 from .toucan import Toucan
 from .yahoo import Yahoo
-from airtable import Airtable
+from .airtable import Airtable
 from .zappier import Zappier
 from .ifttt import Ifttt
 import requests
 
-__version__ = "0.17.0"
+__version__ = "0.18.1"
 
 __github_repo = "jupyter-naas/drivers"
-darkknight = DarkKnight
-airtable = Airtable
-zappier = Zappier
-integromat = Integromat
-ifttt = Ifttt
-yahoo = Yahoo
-ftp = Ftp
-git = Git
-geoLocator = GeoLocator
-gsheet = Gsheet
-health_check = HealthCheck
-email = Email
-mongo = Mongo
-pdf = Pdf
-plotly = Plotly
-html = Html
-cityfalcon = Cityfalcon
-prediction = Prediction
-sentiment_analysis = SentimentAnalysis
-toucan = Toucan
+
+darkknight = DarkKnight()
+airtable = Airtable()
+zappier = Zappier()
+integromat = Integromat()
+ifttt = Ifttt()
+yahoo = Yahoo()
+ftp = Ftp()
+git = Git()
+geoLocator = GeoLocator()
+gsheet = Gsheet()
+health_check = HealthCheck()
+email = Email()
+mongo = Mongo()
+pdf = Pdf()
+plotly = Plotly()
+html = Html()
+cityfalcon = Cityfalcon()
+prediction = Prediction()
+sentiment_analysis = SentimentAnalysis()
+toucan = Toucan()
 
 
 def version():
